Index: trunk/psModules/src/camera/pmFPAfileFitsIO.h
===================================================================
--- trunk/psModules/src/camera/pmFPAfileFitsIO.h	(revision 18601)
+++ trunk/psModules/src/camera/pmFPAfileFitsIO.h	(revision 21363)
@@ -5,6 +5,6 @@
  * @author PAP, IfA
  *
- * @version $Revision: 1.15 $ $Name: not supported by cvs2svn $
- * @date $Date: 2008-07-17 22:38:15 $
+ * @version $Revision: 1.16 $ $Name: not supported by cvs2svn $
+ * @date $Date: 2009-02-06 02:31:24 $
  * Copyright 2004-2005 Institute for Astronomy, University of Hawaii
  */
@@ -27,6 +27,6 @@
                             pmConfig *config
                           );
-/// Read a weight map into the current view
-bool pmFPAviewReadFitsWeight(const pmFPAview *view,  ///< View specifying level of interest
+/// Read a variance map into the current view
+bool pmFPAviewReadFitsVariance(const pmFPAview *view,  ///< View specifying level of interest
                              pmFPAfile *file, ///< FPA file into which to read
                             pmConfig *config
@@ -57,6 +57,6 @@
                            );
 
-/// Write the weight map for the specified view
-bool pmFPAviewWriteFitsWeight(const pmFPAview *view, ///< View specifying level of interest
+/// Write the variance map for the specified view
+bool pmFPAviewWriteFitsVariance(const pmFPAview *view, ///< View specifying level of interest
                               pmFPAfile *file, ///< FPA file to write
                               pmConfig *config ///< Configuration
